camelot.camelot.view.controls.actions.ActionsBox

Package camelot :: Package camelot :: Package view :: Package controls :: Module actions :: Class ActionsBox |
[hide private]
[frames] | no frames]

# Class ActionsBox

source code

A box containing actions to be applied to a form view

Instance Methods | [hide private]
__init__(self, parent, model_thread, entity_getter) | source code
setActions(self, actions) | source code
executeAction(self, button_id) | source code
__del__(self) | source code